package com.cpp.web.service.datafactory;

import cn.hutool.extra.ftp.Ftp;
import cn.hutool.extra.ftp.FtpConfig;
import cn.hutool.extra.ftp.FtpMode;
import com.cpp.web.domain.datafactory.ParsingFileUrl;
import com.cpp.web.domain.datafactory.ParsingType;
import com.cpp.web.mapper.datafactory.ParsingTypeMapper;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.io.FileInputStream;
import java.io.IOException;
import java.nio.charset.Charset;
import java.util.List;
import java.util.Properties;

/**
 * ftp文件解析
 *
 * @author tl
 * @date 2022-05-11 09:51:21
 */
@AllArgsConstructor
@Slf4j
@Service
public class FtpFileParsing {

    private final ParsingTypeMapper parsingTypeMapper;

    /**
     * 解析文件方法
     *
     * @param parsingFileUrls 解析文件路径
     * @return
     */
    public void parsingFile(List<ParsingFileUrl> parsingFileUrls) {

        List<ParsingType> parsingTypes = parsingTypeMapper.selectTypeList();

        if (parsingTypes.size() > 0) {
            Ftp ftp = createParsingFtp();
            if (ftp != null) {
                for (ParsingFileUrl parsingFileUrl : parsingFileUrls) {
                    String url = parsingFileUrl.getUrl();
                    if (ftp.existFile(url)) {
                        List<String> fileNames = ftp.ls(url);
                        for (String fileName : fileNames) {
                            for (ParsingType parsingType : parsingTypes) {
                                if (fileName.contains(parsingType.getFileName())){

                                }
                            }
                        }
                    } else {
                        log.info("ftp服务端，场站：{}，无对应路径，{}", parsingFileUrl.getStationCode(), parsingFileUrl.getUrl());
                    }
                }

                try {
                    ftp.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        } else {
            log.info("未配置文件识别类型标识，无法进行下载解析");
        }
    }

    public Ftp createParsingFtp() {
        Ftp ftp = null;
        Properties prop = new Properties();
        try {
            prop.load(new FileInputStream("ftpConfig.properties"));
            String host = prop.getProperty("ftp.server.host");
            String port = prop.getProperty("ftp.server.port");
            String user = prop.getProperty("ftp.server.username");
            String password = prop.getProperty("ftp.server.password");

            FtpConfig ftpConfig = new FtpConfig();
            try {
                //创建ftp配置
                ftpConfig.setHost(host);
                ftpConfig.setPort(Integer.parseInt(port));
                ftpConfig.setPassword(password);
                ftpConfig.setUser(user);
                //字符集使用UTF-8
                ftpConfig.setCharset(Charset.forName("UTF-8"));
                ftpConfig.setConnectionTimeout(5 * 1000L);

                //设置主动模式连接
                ftp = new Ftp(ftpConfig, FtpMode.Active);
                log.info("{} ：ftp服务器连接成功", ftpConfig.getHost());
            } catch (Exception e) {
                log.error("{} ：ftp服务器连接失败", ftpConfig.getHost(), e);
                if (ftp != null) {
                    ftp.close();
                }
            }
        } catch (Exception ex) {
            log.error("获取ftp配置失败。", ex);
        } finally {
            return ftp;
        }
    }




}
