package com.cpp.web.service.datafactory.impl;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cpp.web.domain.datafactory.BaseParsing;
import com.cpp.web.domain.datafactory.ParsingCft;
import com.cpp.web.mapper.datafactory.ParsingCftMapper;
import com.cpp.web.service.datafactory.ParsingCftService;
import com.cpp.web.service.datafactory.ParsingInterface;
import com.cpp.web.service.station.WindTowerInfoService;
import com.cpp.web.service.station.WindTowerStatusDataService;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.File;
import java.util.Date;
import java.util.List;

/**
 * 测风塔解析业务层实现类
 *
 * @author tl
 * @date 2022-05-11 18:07:03
 */
@Service
@AllArgsConstructor
@Slf4j
@Transactional
public class ParsingCftServiceImpl extends ServiceImpl<ParsingCftMapper, ParsingCft> implements ParsingCftService, ParsingInterface {


    private final Long intervalTime = 300000L;

    private final WindTowerStatusDataService windTowerStatusDataService;

    private final WindTowerInfoService windTowerInfoService;


    @Override
    public boolean save(BaseParsing parsingInfo) {
        return save((ParsingCft) parsingInfo);
    }

    @Override
    public boolean deleteById(Long id) {
        return removeById(id);
    }
//
//    @Override
//    public FileAnalysisStatusDto parsing(File file, ParsingUrl parsingUrl) {
//        FileAnalysisStatusDto fileAnalysisStatusDto = new FileAnalysisStatusDto();
//        fileAnalysisStatusDto.setFileName(file.getName());
//        fileAnalysisStatusDto.setFileType(FileTypeEnum.CFT.getCode()+"");
//
//        try {
//            List<ParsingCftInfo> parsingCftInfos = baseMapper.selectList(Wrappers.lambdaQuery(ParsingCftInfo.class).like(ParsingInfo::getStationCode, parsingUrl.getStationCode()));
//            if (parsingCftInfos.size() > 0) {
//                List<WindTowerInfo> windTowerInfoList = windTowerInfoService.list(Wrappers.lambdaQuery(WindTowerInfo.class)
//                        .eq(WindTowerInfo::getStationCode, parsingUrl.getStationCode()));
//                if (windTowerInfoList.size() > 0) {
//                    List<String> fileContent = FileUtil.getFileContent(file);
//                    for (ParsingCftInfo parsingCftInfo : parsingCftInfos) {
//                        //判断文件名是否符合配置
//                        if (file.getName().indexOf(parsingCftInfo.getFileName()) >= 0) {
//
//                            if (parsingCftInfo.getDataType().equals(FieldUtil.SINGLE)) {
//                                Long time = parsingTime(parsingCftInfo.getTime(), fileContent);
//                                if (time != 0L) {
//                                    WindTowerStatusData windTowerStatusData = new WindTowerStatusData();
//                                    windTowerStatusData.setTime(new Date(time));
//
//                                    windTowerStatusData.setTInst(parsingValue(parsingCftInfo.gettInst(), fileContent));
//                                    windTowerStatusData.setPaInst(parsingValue(parsingCftInfo.getPaInst(), fileContent));
//                                    windTowerStatusData.setRhInst(parsingValue(parsingCftInfo.getRhInst(), fileContent));
//                                    windTowerStatusData.setAirDensity(parsingValue(parsingCftInfo.getAirDensity(), fileContent));
//
//                                    windTowerStatusData.setWsInst10(parsingValue(parsingCftInfo.getWsInst10(), fileContent));
//                                    windTowerStatusData.setWsInst30(parsingValue(parsingCftInfo.getWsInst30(), fileContent));
//                                    windTowerStatusData.setWsInst50(parsingValue(parsingCftInfo.getWsInst50(), fileContent));
//                                    windTowerStatusData.setWsInst60(parsingValue(parsingCftInfo.getWsInst60(), fileContent));
//                                    windTowerStatusData.setWsInst70(parsingValue(parsingCftInfo.getWsInst70(), fileContent));
//                                    windTowerStatusData.setWsInst80(parsingValue(parsingCftInfo.getWsInst80(), fileContent));
//                                    windTowerStatusData.setWsInst90(parsingValue(parsingCftInfo.getWsInst90(), fileContent));
//                                    windTowerStatusData.setWsInst100(parsingValue(parsingCftInfo.getWsInst100(), fileContent));
//                                    windTowerStatusData.setWsInst110(parsingValue(parsingCftInfo.getWsInst110(), fileContent));
//                                    windTowerStatusData.setWsInstHubHeight(parsingValue(parsingCftInfo.getWsInstHubHeight(), fileContent));
//
//                                    windTowerStatusData.setWdInst10(parsingValue(parsingCftInfo.getWdInst10(), fileContent));
//                                    windTowerStatusData.setWdInst30(parsingValue(parsingCftInfo.getWdInst30(), fileContent));
//                                    windTowerStatusData.setWdInst50(parsingValue(parsingCftInfo.getWdInst50(), fileContent));
//                                    windTowerStatusData.setWdInst60(parsingValue(parsingCftInfo.getWdInst60(), fileContent));
//                                    windTowerStatusData.setWdInst70(parsingValue(parsingCftInfo.getWdInst70(), fileContent));
//                                    windTowerStatusData.setWdInst80(parsingValue(parsingCftInfo.getWdInst80(), fileContent));
//                                    windTowerStatusData.setWdInst90(parsingValue(parsingCftInfo.getWdInst90(), fileContent));
//                                    windTowerStatusData.setWdInst100(parsingValue(parsingCftInfo.getWdInst100(), fileContent));
//                                    windTowerStatusData.setWdInst110(parsingValue(parsingCftInfo.getWdInst110(), fileContent));
//                                    windTowerStatusData.setWdInstHubHeight(parsingValue(parsingCftInfo.getWdInstHubHeight(), fileContent));
//
//                                    windTowerStatusData.setStatus(parsingStatus(parsingCftInfo.getStatus(), fileContent));
//                                    windTowerStatusData.setStationCode(parsingUrl.getStationCode());
//
//                                    windTowerStatusData.setEquipmentId(windTowerInfoList.get(0).getEquipmentNo());
//
//                                    windTowerStatusDataService.save(windTowerStatusData);
//                                    fileAnalysisStatusDto.setStatus("1");
//                                    log.info("解析CFT文件：{} 成功！ O(∩_∩)O", file.getName());
//                                } else {
//                                    fileAnalysisStatusDto.setStatus("0");
//                                    fileAnalysisStatusDto.setMessage("解析测风塔文件时间错误");
//                                    log.error("解析CFT文件时间错误");
//                                }
//                            } else {
//                                fileAnalysisStatusDto.setStatus("0");
//                                fileAnalysisStatusDto.setMessage("测风塔暂无多行解析方式");
//                                log.info("cft暂无多行解析方式");
//                            }
//                        }
//                    }
//                } else {
//                    fileAnalysisStatusDto.setStatus("0");
//                    fileAnalysisStatusDto.setMessage("测风塔未配置作为解析使用设备");
//                    log.info("cft未配置作为解析使用设备");
//                }
//
//            }
//        } catch (Exception e) {
//            fileAnalysisStatusDto.setStatus("0");
//            fileAnalysisStatusDto.setMessage("解析测风塔数据失败！");
//            log.error("解析测风塔数据失败！ /(ㄒoㄒ)/~~", e);
//        } finally {
//            return fileAnalysisStatusDto;
//        }
//    }
}
