package com.cpp.web.service.datafactory.impl;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cpp.web.domain.datafactory.BaseParsing;
import com.cpp.web.domain.datafactory.ParsingFj;
import com.cpp.web.mapper.datafactory.ParsingFjMapper;
import com.cpp.web.service.datafactory.ParsingFjService;
import com.cpp.web.service.datafactory.ParsingInterface;
import com.cpp.web.service.station.WindTurbineInfoService;
import com.cpp.web.service.station.WindTurbineStatusDataService;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.File;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 风机解析业务层实现类
 *
 * @author tl
 * @date 2022-05-11 18:07:03
 */
@Service
@AllArgsConstructor
@Slf4j
@Transactional
public class ParsingFjServiceImpl extends ServiceImpl<ParsingFjMapper, ParsingFj> implements ParsingFjService, ParsingInterface {


    private final Long intervalTime = 300000l;

    private final WindTurbineStatusDataService windTurbineStatusDataService;

    private final WindTurbineInfoService windTurbineInfoService;


    @Override
    public boolean save(BaseParsing parsingInfo) {
        return save((ParsingFj) parsingInfo);
    }

    @Override
    public boolean deleteById(Long id) {
        return removeById(id);
    }
//
//    @Override
//    public FileAnalysisStatusDto parsing(File file, ParsingUrl ftpParsingUrl) {
//        FileAnalysisStatusDto fileAnalysisStatusDto = new FileAnalysisStatusDto();
//        fileAnalysisStatusDto.setFileName(file.getName());
//        fileAnalysisStatusDto.setFileType(FileTypeEnum.FJ.getCode()+"");
//
//        try {
//
//
//            List<ParsingFjInfo> parsingFjInfos = baseMapper.selectList(Wrappers.lambdaQuery(ParsingFjInfo.class).like(ParsingInfo::getStationCode, ftpParsingUrl.getStationCode()));
//            if (parsingFjInfos.size() > 0) {
//
//                List<String> fileContent = FileUtil.getFileContent(file);
//                List<WindTurbineInfo> windTurbineInfoList = windTurbineInfoService.list(Wrappers.lambdaQuery(WindTurbineInfo.class).eq(WindTurbineInfo::getStationCode, ftpParsingUrl.getStationCode()));
//
//                for (ParsingFjInfo parsingFjInfo : parsingFjInfos) {
//                    //判断文件名是否符合配置
//                    if (file.getName().indexOf(parsingFjInfo.getFileName()) >= 0) {
//
//                        WindTurbineStatusData windTurbineStatusData = new WindTurbineStatusData();
//
//                        if (parsingFjInfo.getDataType().equals(FieldUtil.SINGLE)) {
//
//                            String fjName = parsingName(parsingFjInfo.getEquipmentName(), fileContent);
//
//                            List<WindTurbineInfo> filterWindTurbineInfos = windTurbineInfoList.stream().filter(i -> i.getName().equals(fjName)).collect(Collectors.toList());
//
//                            if (filterWindTurbineInfos.size() > 0) {
//                                windTurbineStatusData.setEquipmentId(filterWindTurbineInfos.get(0).getEquipmentNo());
//                                Long time = parsingTime(parsingFjInfo.getTime(), fileContent);
//                                if (time != 0l) {
//                                    windTurbineStatusData.setTime(new Date(time));
//
//                                    windTurbineStatusData.setActivePower(parsingValue(parsingFjInfo.getActivePower(), fileContent));
//                                    windTurbineStatusData.setCumulativeGeneratedEnergy(parsingValue(parsingFjInfo.getCumulativeGeneratedEnergy(), fileContent));
//                                    windTurbineStatusData.setDayGridConnectedHours(parsingValue(parsingFjInfo.getDayGridConnectedHours(), fileContent));
//                                    windTurbineStatusData.setWindWheelRatedSpeed(parsingValue(parsingFjInfo.getWindWheelRatedSpeed(), fileContent));
//                                    windTurbineStatusData.setDayElectricQuantity(parsingValue(parsingFjInfo.getDayElectricQuantity(), fileContent));
//                                    windTurbineStatusData.setElectricalCurrent(parsingValue(parsingFjInfo.getElectricalCurrent(), fileContent));
//                                    windTurbineStatusData.setPitchAngle(parsingValue(parsingFjInfo.getPitchAngle(), fileContent));
//                                    windTurbineStatusData.setPowerFactor(parsingValue(parsingFjInfo.getPowerFactor(), fileContent));
//                                    windTurbineStatusData.setReactivePower(parsingValue(parsingFjInfo.getReactivePower(), fileContent));
//                                    windTurbineStatusData.setVoltage(parsingValue(parsingFjInfo.getVoltage(), fileContent));
//                                    windTurbineStatusData.setWd(parsingValue(parsingFjInfo.getWd(), fileContent));
//                                    windTurbineStatusData.setWs(parsingValue(parsingFjInfo.getWs(), fileContent));
//                                    windTurbineStatusData.setT(parsingValue(parsingFjInfo.getT(), fileContent));
//
//                                    windTurbineStatusData.setStatus(parsingStatus(parsingFjInfo.getStatus(), fileContent));
//                                    windTurbineStatusData.setStationCode(parsingFjInfo.getStationCode());
//
//                                    windTurbineStatusDataService.save(windTurbineStatusData);
//                                    log.info("解析FJ文件：" + file.getName() + " 成功！ O(∩_∩)O");
//                                    fileAnalysisStatusDto.setStatus("1");
//                                } else {
//                                    fileAnalysisStatusDto.setStatus("0");
//                                    fileAnalysisStatusDto.setMessage("解析风机文件时间错误");
//                                    log.error("解析FJ文件时间错误");
//                                }
//                            } else {
//                                fileAnalysisStatusDto.setStatus("0");
//                                fileAnalysisStatusDto.setMessage("风机在本地无配置无法解析");
//                                log.info("fj {} 在本地无配置无法解析", fjName);
//                            }
//                        } else {
//                            fileAnalysisStatusDto.setStatus("0");
//                            fileAnalysisStatusDto.setMessage("风机暂无多行解析方式");
//                            log.info("fj暂无多行解析方式");
//                        }
//                    }
//                }
//            }
//
//        } catch (Exception e) {
//            fileAnalysisStatusDto.setStatus("0");
//            fileAnalysisStatusDto.setMessage("解析风机数据错误！");
//            log.error("解析风机数据错误",e);
//        } finally {
//            return fileAnalysisStatusDto;
//        }
//
//    }


}
